Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(416)

Unified Diff: chrome_frame/test_utils.h

Issue 523040: Some Chrome Frame cleanup:... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 10 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome_frame/test/util_unittests.cc ('k') | chrome_frame/test_utils.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome_frame/test_utils.h
===================================================================
--- chrome_frame/test_utils.h (revision 35533)
+++ chrome_frame/test_utils.h (working copy)
@@ -12,6 +12,8 @@
#include "base/file_path.h"
+extern const wchar_t kChromeFrameDllName[];
+
// Helper class used to register different chrome frame DLLs while running
// tests. At construction, this registers the DLL found in the build path.
// At destruction, again registers the DLL found in the build path if another
@@ -34,10 +36,10 @@
static void RegisterDefaults();
private:
// Contains the path of the most recently registered npchrome_tab.dll.
std::wstring new_chrome_frame_dll_path_;
// Contains the path of the npchrome_tab.dll to be registered at destruction.
std::wstring original_dll_path_;
};
« no previous file with comments | « chrome_frame/test/util_unittests.cc ('k') | chrome_frame/test_utils.cc » ('j') | no next file with comments »
@@ -34,10 +36,10 @@
static void RegisterDefaults();
private:
- // Contains the path of the most recently registered npchrome_tab.dll.
+ // Contains the path of the most recently registered Chrome Frame DLL.
std::wstring new_chrome_frame_dll_path_;
@@ -34,10 +36,10 @@
std::wstring new_chrome_frame_dll_path_;
- // Contains the path of the npchrome_tab.dll to be registered at destruction.
+ // Contains the path of the Chrome Frame DLL to be registered at destruction.
std::wstring original_dll_path_;
};

Powered by Google App Engine
This is Rietveld 408576698